import requests
from bs4 import BeautifulSoup
import pandas as pd
import time
from datetime import datetime

def get_ft_data():
    """
    從 http://f.def.life/ 獲取 FT8 和 FT4 頻率數據
    返回兩個 DataFrame，分別包含 FT8 和 FT4 的數據
    """
    try:
        # 獲取網頁內容
        response = requests.get('http://f.def.life/')
        soup = BeautifulSoup(response.text, 'html.parser')
        
        # 調試信息：打印網頁內容
        print("網頁內容長度:", len(response.text))
        print("HTML 內容片段:", response.text[:500])
        
        # 找到所有表格
        tables = soup.find_all('table')
        print(f"找到 {len(tables)} 個表格")
        
        # 找到所有 h2 標題
        headers = soup.find_all('h2')
        print(f"找到 {len(headers)} 個 h2 標題")
        for h in headers:
            print("標題文本:", h.text)
        
        # 解析 FT8 和 FT4 數據表格
        ft8_data = []
        ft4_data = []
        
        for table in tables:
            # 獲取表格標題
            header = table.find_previous('h2')
            if header:
                print(f"處理表格，對應標題: {header.text}")
                
                if 'FT8' in header.text:
                    rows = table.find_all('tr')
                    print(f"FT8表格行數: {len(rows)}")
                    # 解析 FT8 表格
                    for row in rows[1:]:  # 跳過表頭行
                        cols = row.find_all('td')
                        if cols and len(cols) >= 5:
                            freq = cols[0].text.strip()
                            score = cols[1].text.strip()
                            spots = cols[2].text.strip()
                            tx = cols[3].text.strip()
                            rx = cols[4].text.strip()
                            ft8_data.append({
                                'Frequency': freq,
                                'Score': score,
                                'Spots': spots,
                                'TX': tx,
                                'RX': rx
                            })
                            
                elif 'FT4' in header.text:
                    rows = table.find_all('tr')
                    print(f"FT4表格行數: {len(rows)}")
                    # 解析 FT4 表格
                    for row in rows[1:]:  # 跳過表頭行
                        cols = row.find_all('td')
                        if cols and len(cols) >= 5:
                            freq = cols[0].text.strip()
                            score = cols[1].text.strip()
                            spots = cols[2].text.strip()
                            tx = cols[3].text.strip()
                            rx = cols[4].text.strip()
                            ft4_data.append({
                                'Frequency': freq,
                                'Score': score,
                                'Spots': spots,
                                'TX': tx,
                                'RX': rx
                            })
        
        print(f"解析到 FT8 數據條數: {len(ft8_data)}")
        print(f"解析到 FT4 數據條數: {len(ft4_data)}")
        
        # 轉換為 DataFrame
        ft8_df = pd.DataFrame(ft8_data)
        ft4_df = pd.DataFrame(ft4_data)
        
        return ft8_df, ft4_df
        
    except Exception as e:
        print(f"Error fetching data: {e}")
        import traceback
        print(traceback.format_exc())  # 打印完整的錯誤堆棧
        return None, None

def main():
    while True:
        print(f"\n=== 更新時間: {datetime.now().strftime('%Y-%m-%d %H:%M:%S')} ===")
        
        ft8_df, ft4_df = get_ft_data()
        
        if ft8_df is not None and ft4_df is not None:
            print("\nFT8 頻率數據:")
            print(ft8_df)
            print("\nFT4 頻率數據:")
            print(ft4_df)
        
        # 等待5分鐘後再次更新
        time.sleep(300)

if __name__ == "__main__":
    main() 
